@@ -1,10 +1,8 @@
 # The COPYRIGHT file at the top level of this repository contains
 # the full copyright notices and license terms.
 from trytond.pool import Pool
-from . import party
-from . import transaction
-from . import checkout
 
+from . import checkout, party, transaction
 
 __all__ = ['register']
 
