@@ -2,12 +2,12 @@
 # the full copyright notices and license terms.
 from decimal import Decimal
 
-from nereid import (render_template, url_for, flash, redirect, route,
-    current_website)
-from trytond.pool import Pool, PoolMeta
-from trytond.modules.nereid_checkout.checkout import (not_empty_cart,
-    sale_has_non_guest_party, with_company_context)
+from nereid import (
+    current_website, flash, redirect, render_template, route, url_for)
 from nereid.contrib.locale import make_lazy_gettext
+from trytond.modules.nereid_checkout.checkout import (
+    not_empty_cart, sale_has_non_guest_party, with_company_context)
+from trytond.pool import Pool, PoolMeta
 
 _ = make_lazy_gettext('payment_gateway_stripe')
 
