@@ -2,7 +2,8 @@
 # the full copyright notices and license terms.
 
 try:
-    from trytond.modules.payment_gateway_stripe.tests.test_payment_gateway_stripe import suite
+    from trytond.modules.payment_gateway_stripe.tests.test_payment_gateway_stripe import (
+        suite)
 except ImportError:
     from .test_payment_gateway_stripe import suite
 
