@@ -1,24 +1,22 @@
 # The COPYRIGHT file at the top level of this repository contains
 # the full copyright notices and license terms.
-import urllib.request
-import urllib.parse
 import urllib.error
+import urllib.parse
+import urllib.request
 import uuid
-import stripe
-
-from operator import attrgetter
 from decimal import Decimal
 from itertools import groupby
+from operator import attrgetter
 
-from trytond.pool import Pool, PoolMeta
-from trytond.pyson import Eval, Bool, Not
-from trytond.model import ModelView, fields
+import stripe
 from trytond.exceptions import UserError
-from trytond.url import HOSTNAME
+from trytond.model import ModelView, fields
+from trytond.pool import Pool, PoolMeta
+from trytond.pyson import Bool, Eval, Not
 from trytond.transaction import Transaction
+from trytond.url import HOSTNAME
 from trytond.wizard import StateAction
 
-
 stripe.api_version = '2019-05-16'
 
 
